from setuptools import setup, find_packages

setup(
    name="argloom",
    version="0.1.0",
    author="Luiz Gustavo",
    author_email="seuemail@email.com",
    description="Biblioteca Python para criar ARGs (Alternate Reality Games)",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/seuusuario/argpy",
    packages=find_packages(),
    python_requires=">=3.8",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Games/Entertainment",
    ],
)
